You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2011/12/13 10:20:53 UTC

svn commit: r1213622 [1/3] - in /subversion/branches/showing-merge-info: ./ subversion/libsvn_client/ subversion/libsvn_fs_fs/ subversion/libsvn_wc/ subversion/svn/ subversion/tests/cmdline/ subversion/tests/cmdline/getopt_tests_data/ subversion/tests/...

Author: julianfoad
Date: Tue Dec 13 09:20:52 2011
New Revision: 1213622

URL: http://svn.apache.org/viewvc?rev=1213622&view=rev
Log:
On the 'showing-merge-info' branch: Catch up to trunk@1213344.

Modified:
    subversion/branches/showing-merge-info/   (props changed)
    subversion/branches/showing-merge-info/subversion/libsvn_client/client.h
    subversion/branches/showing-merge-info/subversion/libsvn_client/delete.c
    subversion/branches/showing-merge-info/subversion/libsvn_client/merge.c
    subversion/branches/showing-merge-info/subversion/libsvn_client/mergeinfo.c
    subversion/branches/showing-merge-info/subversion/libsvn_client/ra.c
    subversion/branches/showing-merge-info/subversion/libsvn_client/switch.c
    subversion/branches/showing-merge-info/subversion/libsvn_fs_fs/fs_fs.c
    subversion/branches/showing-merge-info/subversion/libsvn_fs_fs/rep-cache-db.sql
    subversion/branches/showing-merge-info/subversion/libsvn_fs_fs/rep-cache.c
    subversion/branches/showing-merge-info/subversion/libsvn_fs_fs/rep-cache.h
    subversion/branches/showing-merge-info/subversion/libsvn_wc/copy.c
    subversion/branches/showing-merge-info/subversion/libsvn_wc/wc_db_wcroot.c
    subversion/branches/showing-merge-info/subversion/svn/main.c
    subversion/branches/showing-merge-info/subversion/svn/merge-cmd.c
    subversion/branches/showing-merge-info/subversion/tests/cmdline/basic_tests.py
    subversion/branches/showing-merge-info/subversion/tests/cmdline/getopt_tests_data/svn_help_log_switch_stdout
    subversion/branches/showing-merge-info/subversion/tests/cmdline/input_validation_tests.py
    subversion/branches/showing-merge-info/subversion/tests/cmdline/merge_tests.py
    subversion/branches/showing-merge-info/subversion/tests/libsvn_client/client-test.c
    subversion/branches/showing-merge-info/subversion/tests/libsvn_wc/op-depth-test.c
    subversion/branches/showing-merge-info/tools/dist/dist.sh

Propchange: subversion/branches/showing-merge-info/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Tue Dec 13 09:20:52 2011
@@ -57,4 +57,4 @@
 /subversion/branches/tree-conflicts:868291-873154
 /subversion/branches/tree-conflicts-notify:873926-874008
 /subversion/branches/uris-as-urls:1060426-1064427
-/subversion/trunk:1177607-1211699
+/subversion/trunk:1177607-1213344

Modified: subversion/branches/showing-merge-info/subversion/libsvn_client/client.h
URL: http://svn.apache.org/viewvc/subversion/branches/showing-merge-info/subversion/libsvn_client/client.h?rev=1213622&r1=1213621&r2=1213622&view=diff
==============================================================================
--- subversion/branches/showing-merge-info/subversion/libsvn_client/delete.c (original)
+++ subversion/branches/showing-merge-info/subversion/libsvn_client/delete.c Tue Dec 13 09:20:52 2011
@@ -272,6 +272,12 @@ delete_urls_multi_repos(const apr_array_
           APR_ARRAY_PUSH(relpaths_list, const char *) = repos_relpath;
         }
 
+      /* Check we identified a non-root relpath.  Return an RA error
+         code for 1.6 compatibility. */
+      if (!repos_relpath || !*repos_relpath)
+        return svn_error_createf(SVN_ERR_RA_ILLEGAL_URL, NULL,
+                                 "URL '%s' not within a repository", uri);
+
       /* Now, test to see if the thing actually exists. */
       SVN_ERR(svn_ra_check_path(ra_session, repos_relpath, SVN_INVALID_REVNUM,
                                 &kind, pool));
--- subversion/branches/showing-merge-info/subversion/libsvn_client/client.h (original)
+++ subversion/branches/showing-merge-info/subversion/libsvn_client/client.h Tue Dec 13 09:20:52 2011
@@ -185,15 +185,15 @@ svn_client__repos_location_segments(apr_
                                     apr_pool_t *pool);
 
 
 /* Set *ANCESTOR_PATH and *ANCESTOR_REVISION to the youngest common
    ancestor path (a path relative to the root of the repository) and
    revision, respectively, of the two locations identified as
-   PATH_OR_URL1@REV1 and PATH_OR_URL2@REV1.  Use the authentication
+   PATH_OR_URL1@REV1 and PATH_OR_URL2@REV2.  Use the authentication
    baton cached in CTX to authenticate against the repository.
-   This function assumes that PATH_OR_URL1@REV1 and PATH_OR_URL2@REV1
+   This function assumes that PATH_OR_URL1@REV1 and PATH_OR_URL2@REV2
    both refer to the same repository.  Use POOL for all allocations. */
 svn_error_t *
-svn_client__get_youngest_common_ancestor(const char **ancestor_path,
+svn_client__get_youngest_common_ancestor(const char **ancestor_relpath,
                                          svn_revnum_t *ancestor_revision,
                                          const char *path_or_url1,
                                          svn_revnum_t rev1,
@@ -185,15 +185,15 @@ svn_client__repos_location_segments(apr_
 
 
-/* Set *ANCESTOR_PATH and *ANCESTOR_REVISION to the youngest common
+/* Set *ANCESTOR_RELPATH and *ANCESTOR_REVISION to the youngest common
    ancestor path (a path relative to the root of the repository) and
    revision, respectively, of the two locations identified as

Modified: subversion/branches/showing-merge-info/subversion/libsvn_client/delete.c
URL: http://svn.apache.org/viewvc/subversion/branches/showing-merge-info/subversion/libsvn_client/delete.c?rev=1213622&r1=1213621&r2=1213622&view=diff
==============================================================================